@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+from zope.interface.interface import Attribute
 from zope.interface import Interface
 
 class IPlominoDatabase(Interface):
@@ -45,3 +45,12 @@ class IPlominoUtils(Interface):
 class IPlominoCache(Interface):
     """Marker interface for PlominoCache
     """
+
+class IXMLImportExportSubscriber(Interface):
+    """Provides import/export to/from XML.
+       Subscribers to IXMLExportEvent MUST implement this interface"""
+    def __call__():
+        """Attahces an XML string representing custom exportable properties
+           to the 'xml_strings' attribute of the event"""
+    def import_xml(xml_string):
+        "Applies information contained in xml string (as returned by __call__)"
\ No newline at end of file
